# # encrypt_url_script.py

from cryptography.hazmat.primitives.ciphers import Cipher, algorithms, modes
from cryptography.hazmat.primitives.kdf.pbkdf2 import PBKDF2HMAC
from cryptography.hazmat.primitives import hashes, padding
from base64 import urlsafe_b64encode
from cryptography.hazmat.backends import default_backend  # Missing import
import os

def encrypt_url(url, password):
    salt = os.urandom(16)
    kdf = PBKDF2HMAC(
        algorithm=hashes.SHA256(),
        length=32,
        salt=salt,
        iterations=100000,
        backend=default_backend()
    )
    key = kdf.derive(password.encode())
    iv = os.urandom(16)
    cipher = Cipher(algorithms.AES(key), modes.CBC(iv), backend=default_backend())
    encryptor = cipher.encryptor()
    padder = padding.PKCS7(algorithms.AES.block_size).padder()
    padded_data = padder.update(url.encode()) + padder.finalize()
    encrypted_data = encryptor.update(padded_data) + encryptor.finalize()
    encrypted_url = urlsafe_b64encode(salt + iv + encrypted_data).decode()
    return encrypted_url

if __name__ == "__main__":
    url = "http://mobilesub.ng/"
    password = "securepassword123"
    encrypted_url = encrypt_url(url, password)
    print(f"Encrypted URL: {encrypted_url}")


# Encrypted URL: LzzMGe-U0M1BAeicSHgoy2Bo6SeccZrW7xuwgtXdJIpaGAJVhsIvzhqKs1YYBnOSdCHOUXiKMbc1o9-rGjibrw==